## MassIQ Client package

This python package is a client package for the MassIQ API. The client object is configured exclusively through the environment.
Required environmental variables to configure the API to connect against

    DOMAIN
    SERVICE_PORT

Your authentication credentials are provided by massflows and must be stored in the following environmental variables

    USER_APP_CLIENT_ID
    USER_APP_CLIENT_SECRET


## Dependency Management

This project uses Poetry to manage dependencies and build the python package.



